Format

Struct Format 

pub struct Format {
    pub bit_order: BitOrder,
    pub byte_order: ByteOrder,
    pub enable_2byte_mode: bool,
}
Controls how the peripheral should treat data received from the DMA.

Fields

bit_order: BitOrder

Configures the bit order for data transmission.

byte_order: ByteOrder

Configures the byte order for data transmission.

  • In 8-bit mode, ByteOrder::Inverted means every two bytes are swapped.
  • In 16-bit mode, this controls the byte order (endianness).
enable_2byte_mode: bool

If true, the width of the output is 16 bits. Otherwise, the width of the output is 8 bits.